@@ -1151,9 +1151,10 @@ Returns t if checkout was successful, nil otherwise."
   (let* ((result menu-items)		; modify in-place
 	 (case-fold-search t)
 	 (type (vc-backend buffer-file-name))
+	 ;; VC works with full path!
 	 (file (if buffer-file-name
-		   (file-name-nondirectory buffer-file-name)
-		 (buffer-name)))
+		   buffer-file-name
+		 (expand-file-name (buffer-name))))
 	 op owner item status)
     (setq op (cond ((null type)
 		    "Register File")
@@ -1178,6 +1179,8 @@ Returns t if checkout was successful, nil otherwise."
 		   ((not (string-equal owner (user-login-name)))
 		    "Steal File Lock")
 		   (t "Check in File")))
+    ;; We do not want the full name in the menu
+    (setq file (file-name-nondirectory file))
     (while (setq item (pop menu-items))
       (and (vectorp item)
 	   (cond ((eq 'vc-next-action (aref item 1))
@@ -1200,4 +1203,24 @@ Returns t if checkout was successful, nil otherwise."
 
 (provide 'vc-hooks)
 
+;; This NEEDS to go AFTER 'vc-hooks, package load only (XEmacs)
+
+;;;###autoload
+(defun vc-load-vc-hooks ()
+  (interactive)
+  (require 'vc-hooks)
+  (vc-find-file-hook))
+
+;;;###autoload
+(and (featurep 'menubar)	
+     (featurep 'xemacs)	
+     (not (or (featurep 'vc-hooks) (featurep 'infodock)))
+     current-menubar
+     (car (find-menu-item current-menubar '("Tools")))
+     (add-submenu '("Tools")
+		  '("VC"
+		   ["Load VC" vc-load-vc-hooks t])
+	"Compare"))
+
+
 ;;; vc-hooks.el ends here
